@@ -29,8 +29,12 @@ import scipy
 import scipy.ndimage
 from matplotlib.patches import Ellipse
 
-
-mpl.rcParams['date.epoch']="0000-12-31T00:00:00"
+# try to use the precise epoch
+mpl.rcParams['date.epoch']='1970-01-01T00:00:00'
+try:
+    mdates.set_epoch('1970-01-01T00:00:00')
+except:
+    pass
 
 class LofarDataBF:
     def __init__(self):
